@@ -3,7 +3,7 @@ from sklearn.metrics import ConfusionMatrixDisplay, confusion_matrix
 
 from trava.ext.results_handlers.plotter import PlotItem
 from trava.ext.results_handlers.scorer_plotter import ScorerPlotter
-from trava.ext.sklearn.scorers import sk
+from trava.ext.sklearn.scorers import sk_binary_with_threshold
 from trava.metric import Metric
 
 
@@ -15,7 +15,7 @@ class ConfMatrixPlotter(ScorerPlotter):
 
 
 class ConfMatrixPlotItem(PlotItem):
-    def __init__(self, normalize: str):
-        self.scorer = sk(confusion_matrix, normalize=normalize)
+    def __init__(self, normalize: str, threshold=None):
+        self.scorer = sk_binary_with_threshold(confusion_matrix, custom_threshold=threshold, normalize=normalize)
         self.plotter = ConfMatrixPlotter()
         self.can_overlap = False
